==> ogre-next-2.3.3-3-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/_ogre_platform_8h.js <==
var _ogre_platform_8h =
[
    [ "__OGRE_HAVE_DIRECTXMATH", "_ogre_platform_8h.html#afc2156f1568d01752c95dc7236018b6d", null ],
    [ "__OGRE_HAVE_NEON", "_ogre_platform_8h.html#a8e0a27b6fe252308fa9eb6700548a78c", null ],
    [ "__OGRE_HAVE_SSE", "_ogre_platform_8h.html#ac00688e814459c227d0c68a0f6352da7", null ],
    [ "_CRT_SECURE_NO_WARNINGS", "_ogre_platform_8h.html#af08ec37a8c99d747fb60fa15bc28678b", null ],
    [ "_OGRE_SIMD_ALIGN_ATTRIBUTE", "_ogre_platform_8h.html#a2f0155896e2458b8547f85aa7f82fd02", null ],
    [ "_SCL_SECURE_NO_WARNINGS", "_ogre_platform_8h.html#abd0a75654ea98e87fa73a854b3f54837", null ],
    [ "DECL_MALLOC", "_ogre_platform_8h.html#aa1730b3ff27777dab53a340f23844db4", null ],
    [ "OGRE_ALIGNED_DECL", "_ogre_platform_8h.html#af405686ffe3dd6aa1b9683a99e5990ed", null ],
    [ "OGRE_ARCH_TYPE", "_ogre_platform_8h.html#a4de9497f1c50d8052061e4870d5cdb42", null ],
    [ "OGRE_ARCHITECTURE_32", "_ogre_platform_8h.html#a37b62784316fecdf49524d6492b2f54e", null ],
    [ "OGRE_ARCHITECTURE_64", "_ogre_platform_8h.html#a338389706b17fb84162ebfa9a4c2195a", null ],
    [ "OGRE_ASSERT_HIGH", "_ogre_platform_8h.html#a66be15613a592905895dbfe8a29a538b", null ],
    [ "OGRE_ASSERT_LOW", "_ogre_platform_8h.html#af98dd4559cd5a6a26dcce6fc7b63df59", null ],
    [ "OGRE_ASSERT_MEDIUM", "_ogre_platform_8h.html#a5e6437487927f2c3e626bf3d9388ab32", null ],
    [ "OGRE_ASSERTS_ENABLED", "_ogre_platform_8h.html#a70359a87e5c2335b17ec0eca70a3a7cc", null ],
    [ "OGRE_BUILD_SUFFIX", "_ogre_platform_8h.html#a922bb8a4073c0e5b0b48acf831b90a64", null ],
    [ "OGRE_COMPILER_BORL", "_ogre_platform_8h.html#ab912259af4a8a0d36f9b40df0d2eaa9f", null ],
    [ "OGRE_COMPILER_CLANG", "_ogre_platform_8h.html#a1e1b3451f5070fe036ad603e9f3c4fa9", null ],
    [ "OGRE_COMPILER_GCCE", "_ogre_platform_8h.html#ab031cce9dea8e68007d20ebe12e4aeda", null ],
    [ "OGRE_COMPILER_GNUC", "_ogre_platform_8h.html#ac98b9fc56eebcda33a152960bd376375", null ],
    [ "OGRE_COMPILER_MSVC", "_ogre_platform_8h.html#a6a94af2b19015f8d92898251ba51b894", null ],
    [ "OGRE_COMPILER_WINSCW", "_ogre_platform_8h.html#a9c256bb4bd2b51e471a4a22a3c735c88", null ],
    [ "OGRE_CPU", "_ogre_platform_8h.html#a719f8e35fd54bc7946246292a772e5cc", null ],
    [ "OGRE_CPU_ARM", "_ogre_platform_8h.html#a87dfb3e6fd0e097cfc22bcf1a936b609", null ],
    [ "OGRE_CPU_MIPS", "_ogre_platform_8h.html#ab5c7b845a9cea9c938dbcc1f9f6fec35", null ],
    [ "OGRE_CPU_PPC", "_ogre_platform_8h.html#a98616201d2102b59d9d10666f3ce8762", null ],
    [ "OGRE_CPU_UNKNOWN", "_ogre_platform_8h.html#ae606623294d49af88c609d5855ee418b", null ],
    [ "OGRE_CPU_X86", "_ogre_platform_8h.html#a03ad9692ca81e2302d7048c9d7695415", null ],
    [ "OGRE_DEBUG_HIGH", "_ogre_platform_8h.html#ae9ca4a25b6e01dedadb359fc285c93fd", null ],
    [ "OGRE_DEBUG_LOW", "_ogre_platform_8h.html#a8515e97868bc6f57d45684fe5cffaf46", null ],
    [ "OGRE_DEBUG_MEDIUM", "_ogre_platform_8h.html#a8b8b5a1578d8ea2f4dc553b1c545367c", null ],
    [ "OGRE_DEBUG_MODE", "_ogre_platform_8h.html#a15ea2b61c3e8ac05db2972f528f94753", null ],
    [ "OGRE_DEBUG_NONE", "_ogre_platform_8h.html#ab0ade039a02b39757fbd2a8c5f87229a", null ],
    [ "OGRE_DEFAULT_LOCALE", "_ogre_platform_8h.html#a9841c02eaa22e4d4d5067cd6cfa9b38f", null ],
    [ "OGRE_DEPRECATED", "_ogre_platform_8h.html#af2652ba9f4945789c869d74d7e67cbcb", null ],
    [ "OGRE_ENDIAN", "_ogre_platform_8h.html#a9af9f9208025e8051717aee67e4e7267", null ],
    [ "OGRE_ENDIAN_BIG", "_ogre_platform_8h.html#a077f6bc75ffd397f81a56ec2cd2838c3", null ],
    [ "OGRE_ENDIAN_LITTLE", "_ogre_platform_8h.html#a600c868168881add7117060af46eb666", null ],
    [ "OGRE_FLEXIBILITY_LEVEL", "_ogre_platform_8h.html#a50837c24594222b3a4cf106190d26c9c", null ],
    [ "OGRE_NORETURN", "_ogre_platform_8h.html#ad9a56ccb609a6502138fae364bf1ed39", null ],
    [ "OGRE_OVERRIDE", "_ogre_platform_8h.html#a437cc0df682035065bde4774a3429f6a", null ],
    [ "OGRE_PLATFORM", "_ogre_platform_8h.html#ad84d3cf520c16ba4ffd3715942f7f175", null ],
    [ "OGRE_PLATFORM_ANDROID", "_ogre_platform_8h.html#a696b7f8c06236aa9ce8b16569fc13985", null ],
    [ "OGRE_PLATFORM_APPLE", "_ogre_platform_8h.html#ac1835ebd5d472ca20f5b4b3a2ddee10a", null ],
    [ "OGRE_PLATFORM_APPLE_IOS", "_ogre_platform_8h.html#a4499f0589d3e524e29fc9016a90f38d3", null ],
    [ "OGRE_PLATFORM_EMSCRIPTEN", "_ogre_platform_8h.html#a813680a39abb8fa11722d6918aa73238", null ],
    [ "OGRE_PLATFORM_FREEBSD", "_ogre_platform_8h.html#afd156284f0635909a814d4a9c745e0ce", null ],
    [ "OGRE_PLATFORM_LINUX", "_ogre_platform_8h.html#ad6ca9e6d3e2b2da8d4ee9e74a8a8f437", null ],
    [ "OGRE_PLATFORM_NACL", "_ogre_platform_8h.html#a1886da46819d5c6333981e2500f29b3c", null ],
    [ "OGRE_PLATFORM_WIN32", "_ogre_platform_8h.html#acbe1943c4784d0e38a71195b186b2648", null ],
    [ "OGRE_PLATFORM_WINRT", "_ogre_platform_8h.html#a5e538aea93661c323e7c86a88514ee48", null ],
    [ "OGRE_QUOTE", "_ogre_platform_8h.html#ab79b68443593aa3abe67d6adea621226", null ],
    [ "OGRE_QUOTE_INPLACE", "_ogre_platform_8h.html#a9201035492049999bc82d4baa25ee090", null ],
    [ "OGRE_RESTRICT_ALIASING", "_ogre_platform_8h.html#a5f33057a2bbced0905164daf8e398d0f", null ],
    [ "OGRE_SIMD_ALIGNED_DECL", "_ogre_platform_8h.html#ae6883e4c8b217447e45bdaec1b1465af", null ],
    [ "OGRE_SIMD_ALIGNMENT", "_ogre_platform_8h.html#a30f03b7a029b1b1303e8f816b68c3368", null ],
    [ "OGRE_WARN", "_ogre_platform_8h.html#ab61ba9272b27cdd1181dd5a18d40b750", null ],
    [ "OGRE_WCHAR_T_STRINGS", "_ogre_platform_8h.html#ade9393c71d42cc913f5c8a9425991d0c", null ],
    [ "RESTRICT_ALIAS", "_ogre_platform_8h.html#a6decd303d90f9cd75d6bb79d51ea2154", null ],
    [ "RESTRICT_ALIAS_RETURN", "_ogre_platform_8h.html#a59a62dcc672b5775f3bd2a8d08bb60a4", null ],
    [ "virtual_l0", "_ogre_platform_8h.html#ab365672a946fca969834e0be99a5649a", null ],
    [ "virtual_l1", "_ogre_platform_8h.html#ad8a102b20f8a115e9787f68fc1045cdf", null ],
    [ "virtual_l2", "_ogre_platform_8h.html#a2c52accfdfe1971a9c62bac16d2bbdc8", null ],
    [ "int16", "_ogre_platform_8h.html#a5c8843f6e8086a9239fed14de8b9d859", null ],
    [ "int32", "_ogre_platform_8h.html#a1c37a43c04753c9ae0c17108c9e6c9d2", null ],
    [ "int64", "_ogre_platform_8h.html#a0d87d229c909a3a971c1b2cea5dc1f8f", null ],
    [ "int8", "_ogre_platform_8h.html#acad7c05003308f9b9be289faab5879f9", null ],
    [ "uint16", "_ogre_platform_8h.html#aa8263b218e7d187ad5ef03a73a6ad7fd", null ],
    [ "uint32", "_ogre_platform_8h.html#adf2a0cf2e77143b5ee1d38a75e289545", null ],
    [ "uint64", "_ogre_platform_8h.html#af7c8391e4119084465186113a849f065", null ],
    [ "uint8", "_ogre_platform_8h.html#a119732ea9d1e88bbddc47b4ac0fa21cb", null ]
];

==> ogre-next-3.0.0-2-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/_ogre_platform_8h.js <==
var _ogre_platform_8h =
[
    [ "__OGRE_HAVE_DIRECTXMATH", "_ogre_platform_8h.html#afc2156f1568d01752c95dc7236018b6d", null ],
    [ "__OGRE_HAVE_NEON", "_ogre_platform_8h.html#a8e0a27b6fe252308fa9eb6700548a78c", null ],
    [ "__OGRE_HAVE_SSE", "_ogre_platform_8h.html#ac00688e814459c227d0c68a0f6352da7", null ],
    [ "_CRT_SECURE_NO_WARNINGS", "_ogre_platform_8h.html#af08ec37a8c99d747fb60fa15bc28678b", null ],
    [ "_OGRE_SIMD_ALIGN_ATTRIBUTE", "_ogre_platform_8h.html#a2f0155896e2458b8547f85aa7f82fd02", null ],
    [ "_SCL_SECURE_NO_WARNINGS", "_ogre_platform_8h.html#abd0a75654ea98e87fa73a854b3f54837", null ],
    [ "DECL_MALLOC", "_ogre_platform_8h.html#aa1730b3ff27777dab53a340f23844db4", null ],
    [ "OGRE_ALIGNED_DECL", "_ogre_platform_8h.html#af405686ffe3dd6aa1b9683a99e5990ed", null ],
    [ "OGRE_ARCH_TYPE", "_ogre_platform_8h.html#a4de9497f1c50d8052061e4870d5cdb42", null ],
    [ "OGRE_ARCHITECTURE_32", "_ogre_platform_8h.html#a37b62784316fecdf49524d6492b2f54e", null ],
    [ "OGRE_ARCHITECTURE_64", "_ogre_platform_8h.html#a338389706b17fb84162ebfa9a4c2195a", null ],
    [ "OGRE_ASSERT_HIGH", "_ogre_platform_8h.html#a66be15613a592905895dbfe8a29a538b", null ],
    [ "OGRE_ASSERT_LOW", "_ogre_platform_8h.html#af98dd4559cd5a6a26dcce6fc7b63df59", null ],
    [ "OGRE_ASSERT_MEDIUM", "_ogre_platform_8h.html#a5e6437487927f2c3e626bf3d9388ab32", null ],
    [ "OGRE_ASSERTS_ENABLED", "_ogre_platform_8h.html#a70359a87e5c2335b17ec0eca70a3a7cc", null ],
    [ "OGRE_BUILD_SUFFIX", "_ogre_platform_8h.html#a922bb8a4073c0e5b0b48acf831b90a64", null ],
    [ "OGRE_COMPILER_BORL", "_ogre_platform_8h.html#ab912259af4a8a0d36f9b40df0d2eaa9f", null ],
    [ "OGRE_COMPILER_CLANG", "_ogre_platform_8h.html#a1e1b3451f5070fe036ad603e9f3c4fa9", null ],
    [ "OGRE_COMPILER_GCCE", "_ogre_platform_8h.html#ab031cce9dea8e68007d20ebe12e4aeda", null ],
    [ "OGRE_COMPILER_GNUC", "_ogre_platform_8h.html#ac98b9fc56eebcda33a152960bd376375", null ],
    [ "OGRE_COMPILER_MSVC", "_ogre_platform_8h.html#a6a94af2b19015f8d92898251ba51b894", null ],
    [ "OGRE_COMPILER_WINSCW", "_ogre_platform_8h.html#a9c256bb4bd2b51e471a4a22a3c735c88", null ],
    [ "OGRE_CPU", "_ogre_platform_8h.html#a719f8e35fd54bc7946246292a772e5cc", null ],
    [ "OGRE_CPU_ARM", "_ogre_platform_8h.html#a87dfb3e6fd0e097cfc22bcf1a936b609", null ],
    [ "OGRE_CPU_MIPS", "_ogre_platform_8h.html#ab5c7b845a9cea9c938dbcc1f9f6fec35", null ],
    [ "OGRE_CPU_PPC", "_ogre_platform_8h.html#a98616201d2102b59d9d10666f3ce8762", null ],
    [ "OGRE_CPU_UNKNOWN", "_ogre_platform_8h.html#ae606623294d49af88c609d5855ee418b", null ],
    [ "OGRE_CPU_X86", "_ogre_platform_8h.html#a03ad9692ca81e2302d7048c9d7695415", null ],
    [ "OGRE_DEBUG_HIGH", "_ogre_platform_8h.html#ae9ca4a25b6e01dedadb359fc285c93fd", null ],
    [ "OGRE_DEBUG_LOW", "_ogre_platform_8h.html#a8515e97868bc6f57d45684fe5cffaf46", null ],
    [ "OGRE_DEBUG_MEDIUM", "_ogre_platform_8h.html#a8b8b5a1578d8ea2f4dc553b1c545367c", null ],
    [ "OGRE_DEBUG_MODE", "_ogre_platform_8h.html#a15ea2b61c3e8ac05db2972f528f94753", null ],
    [ "OGRE_DEBUG_NONE", "_ogre_platform_8h.html#ab0ade039a02b39757fbd2a8c5f87229a", null ],
    [ "OGRE_DEFAULT_LOCALE", "_ogre_platform_8h.html#a9841c02eaa22e4d4d5067cd6cfa9b38f", null ],
    [ "OGRE_DEPRECATED", "_ogre_platform_8h.html#af2652ba9f4945789c869d74d7e67cbcb", null ],
    [ "OGRE_DEPRECATED_ENUM_VER", "_ogre_platform_8h.html#ac3ce24a6691230163ed2e6662feb4c44", null ],
    [ "OGRE_DEPRECATED_VER", "_ogre_platform_8h.html#aa3f232542ea15f70a374031a09ba946b", null ],
    [ "OGRE_ENDIAN", "_ogre_platform_8h.html#a9af9f9208025e8051717aee67e4e7267", null ],
    [ "OGRE_ENDIAN_BIG", "_ogre_platform_8h.html#a077f6bc75ffd397f81a56ec2cd2838c3", null ],
    [ "OGRE_ENDIAN_LITTLE", "_ogre_platform_8h.html#a600c868168881add7117060af46eb666", null ],
    [ "OGRE_FLEXIBILITY_LEVEL", "_ogre_platform_8h.html#a50837c24594222b3a4cf106190d26c9c", null ],
    [ "OGRE_GCC_VISIBILITY", "_ogre_platform_8h.html#aebf254ba26e3fd6b375e849fd10f2c2f", null ],
    [ "OGRE_NORETURN", "_ogre_platform_8h.html#ad9a56ccb609a6502138fae364bf1ed39", null ],
    [ "OGRE_PLATFORM", "_ogre_platform_8h.html#ad84d3cf520c16ba4ffd3715942f7f175", null ],
    [ "OGRE_PLATFORM_ANDROID", "_ogre_platform_8h.html#a696b7f8c06236aa9ce8b16569fc13985", null ],
    [ "OGRE_PLATFORM_APPLE", "_ogre_platform_8h.html#ac1835ebd5d472ca20f5b4b3a2ddee10a", null ],
    [ "OGRE_PLATFORM_APPLE_IOS", "_ogre_platform_8h.html#a4499f0589d3e524e29fc9016a90f38d3", null ],
    [ "OGRE_PLATFORM_EMSCRIPTEN", "_ogre_platform_8h.html#a813680a39abb8fa11722d6918aa73238", null ],
    [ "OGRE_PLATFORM_FREEBSD", "_ogre_platform_8h.html#afd156284f0635909a814d4a9c745e0ce", null ],
    [ "OGRE_PLATFORM_LINUX", "_ogre_platform_8h.html#ad6ca9e6d3e2b2da8d4ee9e74a8a8f437", null ],
    [ "OGRE_PLATFORM_UNUSED", "_ogre_platform_8h.html#a85e574072061523a73f98a98710eaef6", null ],
    [ "OGRE_PLATFORM_WIN32", "_ogre_platform_8h.html#acbe1943c4784d0e38a71195b186b2648", null ],
    [ "OGRE_PLATFORM_WINRT", "_ogre_platform_8h.html#a5e538aea93661c323e7c86a88514ee48", null ],
    [ "OGRE_QUOTE", "_ogre_platform_8h.html#ab79b68443593aa3abe67d6adea621226", null ],
    [ "OGRE_QUOTE_INPLACE", "_ogre_platform_8h.html#a9201035492049999bc82d4baa25ee090", null ],
    [ "OGRE_RESTRICT_ALIASING", "_ogre_platform_8h.html#a5f33057a2bbced0905164daf8e398d0f", null ],
    [ "OGRE_SIMD_ALIGNED_DECL", "_ogre_platform_8h.html#ae6883e4c8b217447e45bdaec1b1465af", null ],
    [ "OGRE_SIMD_ALIGNMENT", "_ogre_platform_8h.html#a30f03b7a029b1b1303e8f816b68c3368", null ],
    [ "OGRE_WARN", "_ogre_platform_8h.html#ab61ba9272b27cdd1181dd5a18d40b750", null ],
    [ "OGRE_WCHAR_T_STRINGS", "_ogre_platform_8h.html#ade9393c71d42cc913f5c8a9425991d0c", null ],
    [ "RESTRICT_ALIAS", "_ogre_platform_8h.html#a6decd303d90f9cd75d6bb79d51ea2154", null ],
    [ "RESTRICT_ALIAS_RETURN", "_ogre_platform_8h.html#a59a62dcc672b5775f3bd2a8d08bb60a4", null ],
    [ "virtual_l0", "_ogre_platform_8h.html#ab365672a946fca969834e0be99a5649a", null ],
    [ "virtual_l1", "_ogre_platform_8h.html#ad8a102b20f8a115e9787f68fc1045cdf", null ],
    [ "virtual_l2", "_ogre_platform_8h.html#a2c52accfdfe1971a9c62bac16d2bbdc8", null ],
    [ "Ogre::int16", "namespace_ogre.html#a5c8843f6e8086a9239fed14de8b9d859", null ],
    [ "Ogre::int32", "namespace_ogre.html#a1c37a43c04753c9ae0c17108c9e6c9d2", null ],
    [ "Ogre::int64", "namespace_ogre.html#a0d87d229c909a3a971c1b2cea5dc1f8f", null ],
    [ "Ogre::int8", "namespace_ogre.html#acad7c05003308f9b9be289faab5879f9", null ],
    [ "Ogre::uint16", "namespace_ogre.html#aa8263b218e7d187ad5ef03a73a6ad7fd", null ],
    [ "Ogre::uint32", "namespace_ogre.html#adf2a0cf2e77143b5ee1d38a75e289545", null ],
    [ "Ogre::uint64", "namespace_ogre.html#af7c8391e4119084465186113a849f065", null ],
    [ "Ogre::uint8", "namespace_ogre.html#a119732ea9d1e88bbddc47b4ac0fa21cb", null ]
];
